@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -40,7 +40,7 @@ INDENT_IDS = 26
 RESOURCES_LOG_FILES = set(['project', 'source', 'dataset', 'dataset_train',
                            'dataset_test', 'dataset_gen', 'dataset_cluster',
                            'dataset_parts', 'dataset_multi', 'models',
-                           'ensembles', 'evaluations',
+                           'ensembles', 'evaluations', 'optimls',
                            'clusters', 'batch_prediction', 'batch_centroid',
                            'anomalies', 'batch_anomaly_score', 'sample',
                            'associations', 'time_series', "deepnets",
@@ -62,7 +62,7 @@ STATUS_CODES = {
 }
 
 GROUP_RESOURCES = ["project", "execution"]
-COMPOSED_RESOURCES = ["cluster", "ensemble", "fusion", "composites"]
+COMPOSED_RESOURCES = ["cluster", "ensemble", "fusion", "composites", "optiml"]
 
 
 def retrieve_resources(directory):
@@ -204,7 +204,7 @@ def filter_resource_types(delete_list, resource_types):
        only those resources will be deleted.
 
     """
-    if resource_types is not None:
+    if resource_types is not None and resource_types:
         delete_list = [resource for resource in delete_list if
                        bigml.api.get_resource_type(resource) in resource_types]
     return delete_list
@@ -220,6 +220,7 @@ def filtered_selectors(args, api):
         ("project", args.project_tag, api.list_projects, None),
         ("execution", args.execution_tag, api.list_executions, None),
         ("cluster", args.cluster_tag, api.list_clusters, None),
+        ("optiml", args.optiml_tag, api.list_optimls, None),
         ("source", args.source_tag, api.list_sources, None),
         ("dataset", args.dataset_tag, api.list_datasets,
          "cluster_status=false"),
@@ -354,10 +355,6 @@ def delete_resources(command_args, api, deleted_list=None):
     if command_args.from_dir:
         delete_list.extend(retrieve_resources(command_args.from_dir))
 
-    # filter resource_types if any
-    delete_list = filter_resource_types(delete_list,
-                                        command_args.resource_types_)
-
     # by time interval and tag (plus filtered resource_types)
     time_qs_list = time_interval_qs(command_args, api)
     delete_list.extend(get_delete_list(command_args, api, time_qs_list))
@@ -366,6 +363,10 @@ def delete_resources(command_args, api, deleted_list=None):
     filter_qs_list = filter_qs(command_args)
     delete_list.extend(get_delete_list(command_args, api, filter_qs_list))
 
+    # filter resource_types if any
+    delete_list = filter_resource_types(delete_list,
+                                        command_args.resource_types_)
+
     delete_list = [resource_id for resource_id in delete_list \
         if resource_id not in deleted_list]
     # if there are projects or executions, delete them first
