@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -55,7 +55,7 @@ SUBCOMMANDS = ["main", "analyze", "cluster", "anomaly", "sample", "dataset",
                "delete", "report", "reify", "project", "association",
                "logistic-regression", "topic-model", "time-series",
                "execute", "whizzml", "export", "deepnet", "retrain",
-               "linear-regression", "pca", "fusion", "connector"]
+               "linear-regression", "pca", "fusion", "connector", "source"]
 
 
 MAIN = SUBCOMMANDS[0]
@@ -79,7 +79,7 @@ def create_parser(general_defaults={}, constants={}, subcommand=MAIN):
     version = pkg_resources.require("BigMLer")[0].version
     version_text = """\
 BigMLer %s - A Higher Level API to BigML's API
-Copyright 2012-2021 BigML
+Copyright 2012-2022 BigML
 
 Licensed under the Apache License, Version 2.0 (the \"License\"); you may
 not use this file except in compliance with the License. You may obtain
@@ -148,6 +148,10 @@ under the License.""" % version
         '--sample-rate': main_options['--sample-rate'],
         '--seed': main_options['--seed']}
 
+    subcommand_options["source"] = source_options
+    subcommand_options["source"].update(common_options)
+
+
     defaults = general_defaults["BigMLer whizzml"]
     subcommand_options["whizzml"] = get_whizzml_options(defaults=defaults)
     subcommand_options["whizzml"].update(common_options)
