@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -88,9 +88,10 @@ def has_train(args):
     """Returns if some kind of train data is given in args.
 
     """
-    return any(has_value(args, ["training_set", "source", "dataset",
-                                "datasets", "source_file", "dataset_file",
-                                "train_stdin", "source_tag", "dataset_tag"]))
+    return any(has_value(args, ["training_set", "source", "source_in",
+                                "dataset", "datasets", "source_file",
+                                "dataset_file", "train_stdin", "source_tag",
+                                "dataset_tag"]))
 
 
 def has_source(args):
@@ -160,6 +161,23 @@ def get_flags(args):
     return flags, train_stdin, test_stdin
 
 
+def comma_to_list(comma_arg, separator, none=False):
+    """Returns the list of elements defined in a comma-separated string
+    adapting to the actual command separator
+
+    """
+    if comma_arg is None and none:
+        return None
+
+    if comma_arg:
+        list_arg = [option.strip() for option in
+            comma_arg.split(separator)]
+    else:
+        list_arg = []
+
+    return list_arg
+
+
 def get_command_message(args):
     """Rebuilds the command message based on the args list
 
@@ -380,124 +398,71 @@ def get_output_args(api, command_args, resume):
 
     # Parses dataset fields if provided.
     try:
-        if command_args.dataset_fields:
-            dataset_fields_arg = [
-                field.strip() for field in command_args.dataset_fields.split(
-                    command_args.args_separator)]
-            command_args.dataset_fields_ = dataset_fields_arg
-        else:
-            command_args.dataset_fields_ = []
+        command_args.dataset_fields_ = comma_to_list(command_args.dataset_fields,
+                                                     command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses model input fields if provided.
     try:
-        if command_args.model_fields:
-            model_fields_arg = [
-                field.strip() for field in command_args.model_fields.split(
-                    command_args.args_separator)]
-            command_args.model_fields_ = model_fields_arg
-        else:
-            command_args.model_fields_ = []
+        command_args.model_fields_ = comma_to_list(command_args.model_fields,
+                                                   command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses cluster input fields if provided.
     try:
-        if command_args.cluster_fields:
-            cluster_fields_arg = [
-                field.strip() for field in command_args.cluster_fields.split(
-                    command_args.args_separator)]
-            command_args.cluster_fields_ = cluster_fields_arg
-        else:
-            command_args.cluster_fields_ = []
+        command_args.cluster_fields_ = comma_to_list(command_args.cluster_fields,
+                                                     command_args.args_separator)
     except AttributeError:
         pass
 
-
     # Parses association input fields if provided.
     try:
-        if command_args.association_fields:
-            association_fields_arg = [
-                field.strip() for field in \
-                command_args.association_fields.split( \
-                command_args.args_separator)]
-            command_args.association_fields_ = association_fields_arg
-        else:
-            command_args.association_fields_ = []
+        command_args.association_fields_ = comma_to_list(
+            command_args.association_fields, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses anomaly input fields if provided.
     try:
-        if command_args.anomaly_fields:
-            anomaly_fields_arg = [
-                field.strip() for field in command_args.anomaly_fields.split(
-                    command_args.args_separator)]
-            command_args.anomaly_fields_ = anomaly_fields_arg
-        else:
-            command_args.anomaly_fields_ = []
+        command_args.anomaly_fields_ = comma_to_list(
+            command_args.anomaly_fields, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses logistic regression input fields if provided.
     try:
-        if command_args.logistic_fields:
-            logistic_fields_arg = [
-                field.strip() for field in command_args.logistic_fields.split(
-                    command_args.args_separator)]
-            command_args.logistic_fields_ = logistic_fields_arg
-        else:
-            command_args.logistic_fields_ = []
+        command_args.logistic_fields_ = comma_to_list(
+            command_args.logistic_fields, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses linear regression input fields if provided.
     try:
-        if command_args.linear_fields:
-            linear_fields_arg = [
-                field.strip() for field in command_args.linear_fields.split(
-                    command_args.args_separator)]
-            command_args.linear_fields_ = linear_fields_arg
-        else:
-            command_args.linear_fields_ = []
+        command_args.linear_fields_ = comma_to_list(
+            command_args.linear_fields, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses deepnet input fields if provided.
     try:
-        if command_args.deepnet_fields:
-            deepnet_fields_arg = [
-                field.strip() for field in command_args.deepnet_fields.split(
-                    command_args.args_separator)]
-            command_args.deepnet_fields_ = deepnet_fields_arg
-        else:
-            command_args.deepnet_fields_ = []
+        command_args.deepnet_fields_ = comma_to_list(
+            command_args.deepnet_fields, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses topic model fields if provided.
     try:
-        if command_args.topic_fields:
-            topic_fields_arg = [
-                field.strip() for field in command_args.topic_fields.split(
-                    command_args.args_separator)]
-            command_args.topic_model_fields_ = topic_fields_arg
-        else:
-            command_args.topic_model_fields_ = []
+        command_args.topic_fields_ = comma_to_list(
+            command_args.topic_fields, command_args.args_separator)
     except AttributeError:
         pass
 
-
     # Parses pca fields if provided.
     try:
-        if command_args.pca_fields:
-            pca_fields_arg = [
-                field.strip() for field in command_args.pca_fields.split(
-                    command_args.args_separator)]
-            command_args.pca_fields_ = pca_fields_arg
-        else:
-            command_args.pca_fields_ = []
+        command_args.pca_fields_ = comma_to_list(
+            command_args.pca_fields, command_args.args_separator)
     except AttributeError:
         pass
 
@@ -513,37 +478,22 @@ def get_output_args(api, command_args, resume):
 
     # Parses imports for scripts and libraries.
     try:
-        if command_args.imports:
-            imports_arg = [
-                field.strip() for field in command_args.imports.split(
-                    command_args.args_separator)]
-            command_args.imports_ = imports_arg
-        else:
-            command_args.imports_ = []
+        command_args.imports_ = comma_to_list(
+            command_args.imports, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses objective fields for time-series.
     try:
-        if command_args.objectives:
-            objective_fields_arg = [
-                field.strip() for field in command_args.objectives.split(
-                    command_args.args_separator)]
-            command_args.objective_fields_ = objective_fields_arg
-        else:
-            command_args.objective_fields_ = []
+        command_args.objectives_ = comma_to_list(
+            command_args.objectives, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses range.
     try:
-        if command_args.range:
-            range_arg = [
-                value.strip() for value in command_args.range.split(
-                    command_args.args_separator)]
-            command_args.range_ = range_arg
-        else:
-            command_args.range_ = []
+        command_args.range_ = comma_to_list(
+            command_args.range, command_args.args_separator)
     except AttributeError:
         pass
 
@@ -813,13 +763,8 @@ def get_output_args(api, command_args, resume):
 
     # Parses models list for fusions if provided.
     try:
-        if command_args.fusion_models:
-            fusion_models_arg = [
-                model.strip() for model in command_args.fusion_models.split(
-                    command_args.args_separator)]
-            command_args.fusion_models_ = fusion_models_arg
-        else:
-            command_args.fusion_models_ = []
+        command_args.fusion_models_ = comma_to_list(
+            command_args.fusion_models, command_args.args_separator)
     except AttributeError:
         pass
 
@@ -857,40 +802,103 @@ def get_output_args(api, command_args, resume):
 
     # Parses cluster names to generate datasets if provided
     try:
-        if command_args.cluster_datasets:
-            cluster_datasets_arg = [
-                dataset.strip() for dataset in
-                command_args.cluster_datasets.split(
-                    command_args.args_separator)]
-            command_args.cluster_datasets_ = cluster_datasets_arg
-        else:
-            command_args.cluster_datasets_ = []
+        command_args.cluster_datasets_ = comma_to_list(
+            command_args.cluster_datasets, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses cluster names to generate models if provided
     try:
-        if command_args.cluster_models:
-            cluster_models_arg = [
-                model.strip() for model in
-                command_args.cluster_models.split(
-                    command_args.args_separator)]
-            command_args.cluster_models_ = cluster_models_arg
-        else:
-            command_args.cluster_models_ = []
+        command_args.cluster_models_ = comma_to_list(
+            command_args.cluster_models, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses summary_fields to exclude from the clustering algorithm
     try:
-        if command_args.summary_fields:
-            summary_fields_arg = [
+        command_args.summary_fields_ = comma_to_list(
+            command_args.summary_fields, command_args.args_separator)
+    except AttributeError:
+        pass
+
+    # Parses image_augmentations
+    try:
+        command_args.image_augmentations_ = comma_to_list(
+            command_args.image_augmentations, command_args.args_separator)
+    except AttributeError:
+        pass
+
+    # Parses add_sources
+    try:
+        command_args.add_sources_ = comma_to_list(
+            command_args.add_sources, command_args.args_separator)
+    except AttributeError:
+        pass
+
+    # Parses remove_sources
+    try:
+        command_args.remove_sources_ = comma_to_list(
+            command_args.remove_sources, command_args.args_separator)
+    except AttributeError:
+        pass
+
+    # Parses delete_sources
+    try:
+        command_args.delete_sources_ = comma_to_list(
+            command_args.delete_sources, command_args.args_separator)
+    except AttributeError:
+        pass
+
+    # Parses sources
+    try:
+        command_args.sources_ = comma_to_list(
+            command_args.sources, command_args.args_separator, none=True)
+    except AttributeError:
+        pass
+
+    # Parses include_extracted_features
+    try:
+        if command_args.include_extracted_features:
+            include_extracted_features_arg = [
                 field.strip() for field in
-                command_args.summary_fields.split(
+                command_args.include_extracted_features.split(
                     command_args.args_separator)]
-            command_args.summary_fields_ = summary_fields_arg
+            if include_extracted_features_arg == ["all"]:
+                include_extracted_features_arg = True
+            elif include_extracted_features_arg == ["none"]:
+                include_extracted_features_arg = False
+            command_args.include_extracted_features_ = \
+                include_extracted_features_arg
         else:
-            command_args.summary_fields_ = []
+            command_args.include_extracted_features_ = []
+    except AttributeError:
+        pass
+
+    # Parses row_components
+    try:
+        command_args.row_components_ = comma_to_list(
+            command_args.row_components, command_args.args_separator)
+    except AttributeError:
+        pass
+
+
+    # Parses row_indices
+    try:
+        command_args.row_indices_ = comma_to_list(
+            command_args.row_indices, command_args.args_separator)
+    except AttributeError:
+        pass
+
+    # Parses id_fields to exclude from the anomaly detector algorithm
+    try:
+        if command_args.id_fields:
+            id_fields_arg = [
+                field.strip() for field in
+                command_args.id_fields.split(
+                    command_args.args_separator)]
+            command_args.id_fields_ = id_fields_arg
+        else:
+            command_args.id_fields_ = []
     except AttributeError:
         pass
 
@@ -936,25 +944,15 @@ def get_output_args(api, command_args, resume):
 
     # Parses sample row fields
     try:
-        if command_args.row_fields:
-            row_fields_arg = [field.strip() for field in
-                              command_args.row_fields.split(
-                                  command_args.args_separator)]
-            command_args.row_fields_ = row_fields_arg
-        else:
-            command_args.row_fields_ = []
+        command_args.row_fields_ = comma_to_list(
+            command_args.row_fields, command_args.args_separator)
     except AttributeError:
         pass
 
     # Parses sample stat_fields
     try:
-        if command_args.stat_fields:
-            stat_fields_arg = [field.strip() for field in
-                               command_args.stat_fields.split(
-                                   command_args.args_separator)]
-            command_args.stat_fields_ = stat_fields_arg
-        else:
-            command_args.stat_fields_ = []
+        command_args.stat_fields_ = comma_to_list(
+            command_args.stat_fields, command_args.args_separator)
     except AttributeError:
         pass
 
@@ -1123,6 +1121,15 @@ def transform_args(command_args, flags, api):
     except AttributeError:
         pass
 
+    # Reads a json row_values object.
+    command_args.row_values = None
+    try:
+        if command_args.row_values_json:
+            row_values = u.read_json(command_args.row_values_json)
+            command_args.row_values = row_values
+    except AttributeError:
+        pass
+
     # Adds default tags unless that it is requested not to do so.
     try:
         if command_args.no_tag:
