@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -32,10 +32,27 @@ import bigmler.utils as u
 import bigmler.resourcesapi.sources as r
 import bigmler.checkpoint as c
 import bigmler.processing.projects as pp
+import bigmler.processing.annotations as an
 
+from bigmler.processing.args import has_train
 from bigmler.train_reader import TrainReader
 
-MONTECARLO_FACTOR = 200
+
+def needs_source_update(args):
+    """Checks whether the arguments passed need to be change at update time
+
+    """
+    return (args.field_attributes_ or args.types_ or args.user_locale
+            or args.json_args.get('source') or args.import_fields or
+            (hasattr(args, "add_sources") and args.add_sources_) or
+            (hasattr(args, "sources") and args.sources_ is not None) or
+            (hasattr(args, "sources_in") and args.sources_in is not None) or
+            (hasattr(args, "remove_sources") and args.remove_sources_) or
+            (hasattr(args, "delete_sources") and args.delete_sources_) or
+            (hasattr(args, "close") and args.close is not None) or
+            (hasattr(args, "row_components") and args.row_components) or
+            (hasattr(args, "row_indices") and args.row_indices) or
+            (hasattr(args, "row_values") and args.row_values))
 
 
 def test_source_processing(api, args, resume,
@@ -100,6 +117,29 @@ def test_source_processing(api, args, resume,
     return test_source, resume, csv_properties, fields
 
 
+def images_data_set(data_set, args, session_file):
+    """Adding images information when the data_set contains the images
+    directory.
+
+    """
+    try:
+        args.images_dir = None
+        args.images_file = None
+        if os.path.isdir(data_set):
+            # When data_set is a directory, we assume it will contain images
+            args.images_dir = data_set
+        elif args.annotations_file:
+            args.images_file = data_set
+
+        if args.annotations_language is not None:
+            data_set = an.bigml_coco_file(args, session_file)
+        elif os.path.isdir(data_set) or args.images_file is not None:
+            data_set = an.bigml_metadata(args)
+    except TypeError:
+        pass
+    return data_set, args
+
+
 def source_processing(api, args, resume,
                       csv_properties=None,
                       multi_label_data=None,
@@ -109,6 +149,9 @@ def source_processing(api, args, resume,
     """
     source = None
     fields = None
+    if args.sources_in:
+        args.sources_ = u.read_sources(args.sources)
+
     if (args.training_set or (
             hasattr(args, "evaluate") and args.evaluate and args.test_set)):
         # If resuming, try to extract args.source form log files
@@ -127,16 +170,30 @@ def source_processing(api, args, resume,
         # Check if there's a created project for it
         args.project_id = pp.project_processing(
             api, args, resume, session_file=session_file, path=path, log=log)
-        source_args = r.set_source_args(args,
-                                        multi_label_data=multi_label_data,
-                                        data_set_header=data_set_header)
-        source = r.create_source(data_set, source_args, args, api,
-                                 path, session_file, log)
+
+        # If --annotations-language is used, the data_set can be a directory
+        # that contains both images and annotation files that need to be
+        # preprocessed
+        data_set, args = images_data_set(data_set, args, session_file)
+        source_args = r.set_source_args(
+            args, multi_label_data=multi_label_data,
+            data_set_header=data_set_header)
+        source = r.create_source(
+            data_set, source_args, args, api, path, session_file, log)
 
     # If a source is provided either through the command line or in resume
     # steps, we use it.
     elif args.source:
         source = bigml.api.get_source_id(args.source)
+    elif args.sources_ is not None and not has_train(args):
+        # if no data or source ID is provided and a list of sources
+        # (which might even be empty e.g. --sources "")
+        # is given, it creates a composite
+        source_args = r.set_source_args(
+            args, multi_label_data=multi_label_data,
+            data_set_header=data_set_header)
+        source = r.create_source(
+            data_set, source_args, args, api, path, session_file, log)
 
     # If we already have source, we check that is finished , extract the
     # fields, and update them if needed.
@@ -154,17 +211,22 @@ def source_processing(api, args, resume,
                         bigml_locale(args.user_locale) ==
                         source_parser['locale']):
                     args.user_locale = None
-        fields = Fields(source['object']['fields'], **csv_properties)
-
-        if (args.field_attributes_ or args.types_ or args.user_locale
-                or args.json_args.get('source') or args.import_fields):
+        fields = Fields(source['object'].get('fields', {}),
+                        **csv_properties)
+        if needs_source_update(args) or (data_set is None and args.images_file
+                and args.annotations_file):
+            if source["object"].get("closed", False):
+                # need to clone the source to edit it
+                source = r.clone_source(source, args, api, path,
+                                        session_file, log)
             # avoid updating project_id in source
             project_id, args.project_id = args.project_id, None
-            source_args = r.set_source_args(args, fields=fields)
+            source_args = r.set_source_args(args, fields=fields, update=True)
             source = r.update_source(source, source_args, args, api,
                                      session_file)
             args.project_id = project_id
-            fields = Fields(source['object']['fields'], **csv_properties)
+            fields = Fields(source['object'].get('fields', {}),
+                            **csv_properties)
 
     return source, resume, csv_properties, fields
 
