@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,6 +18,9 @@
 import os
 import time
 import json
+import shutil
+
+
 from bigmler.tests.world import world, res_filename
 from subprocess import check_call, CalledProcessError
 from bigml.api import check_resource
@@ -46,13 +49,19 @@ from bigmler.tests.basic_association_steps import \
     i_create_association, i_check_create_association
 from bigmler.tests.basic_logistic_r_steps import \
     i_create_all_lr_resources, i_check_create_lr_model
+from bigmler.tests.basic_deepnet_steps import \
+    i_create_all_dn_resources, i_check_create_dn_model
 from bigmler.tests.basic_pca_steps import \
     i_create_all_pca_resources, i_check_create_pca_model
+from bigmler.tests.composite_steps import i_check_create_composite
 from bigmler.tests.common_steps import check_debug
 from bigmler.reports import REPORTS_DIR
 from nose.tools import ok_, assert_equal, assert_not_equal, assert_almost_equal
 
 
+DECIMAL_PLACES = 3
+
+
 def shell_execute(command, output, test=None, options=None,
                   test_rows=None, project=True):
     """Excute bigmler command in shell
@@ -202,6 +211,41 @@ def i_create_source_with_locale(step, data=None, locale=None,
         assert False
 
 
+#@step(r'I create a BigML source from file "([^"]*)"
+# storing results in "(.*)"$')
+def i_create_composite_source(step, data=None, output=None):
+    ok_(data is not None and output is not None)
+    command = ("bigmler --train " + res_filename(data) + " --output " + output +
+               " --no-dataset --no-model --store")
+    command = check_debug(command)
+    try:
+        retcode = check_call(command, shell=True)
+        ok_(retcode >=0)
+        world.directory = os.path.dirname(output)
+        world.folders.append(world.directory)
+        world.output = output
+    except OSError as e:
+        assert False
+
+#@step(r'I create a BigML source from file "([^"]*)"
+# storing results in "(.*)"$')
+def i_create_source(step, data=None, output_dir=None):
+    ok_(data is not None and output_dir is not None)
+    output = os.path.join(output_dir, "tmp.txt")
+    command = ("bigmler source --data " + res_filename(data) +
+               " --output-dir " + output_dir +
+               " --store")
+    command = check_debug(command)
+    try:
+        retcode = check_call(command, shell=True)
+        ok_(retcode >=0)
+        world.directory = os.path.dirname(output)
+        world.folders.append(world.directory)
+        world.output = output
+    except OSError as e:
+        assert False
+
+
 #@step(r'I create BigML resources uploading train "(.*?)" file to create model
 # and log in "([^"]*)"$')
 def i_create_all_resources_to_model(step, data=None, output=None):
@@ -1353,37 +1397,26 @@ def i_check_predictions_file(step, predictions_file, check_file):
 
 #@step(r'the local prediction file is like "(.*)"')
 def i_check_predictions(step, check_file):
-    check_file = res_filename(check_file)
-    predictions_file = world.output
+    check_file_path = res_filename(check_file)
+    predictions_file_path = world.output
     import traceback
     try:
-        with UnicodeReader(predictions_file) as predictions_file:
-            with UnicodeReader(check_file) as check_file:
+        with UnicodeReader(predictions_file_path) as predictions_file:
+            with UnicodeReader(check_file_path) as check_file:
                 for row in predictions_file:
                     check_row = next(check_file)
                     assert_equal(len(check_row), len(row))
                     for index in range(len(row)):
-                        dot = row[index].find(".")
-                        decimal_places = 1
-                        if dot > 0 or (check_row[index].find(".") > 0
-                                       and check_row[index].endswith(".0")):
-                            try:
-                                decimal_places = min(len(row[index]),
-                                                     len(check_row[index])) \
-                                    - dot - 1
-                                row[index] = round(float(row[index]),
-                                                   decimal_places)
-                                check_row[index] = round(float(check_row[ \
-                                    index]), decimal_places)
-                            except ValueError:
-                                decimal_places = 1
-                            # we set 10 decimal places as max precision
-                            decimal_places = min([10, decimal_places])
-                            assert_almost_equal(check_row[index], row[index],
-                                                places=(decimal_places - 1))
-                        else:
+                        try:
+                            check_row[index] = float(check_row[index])
+                            row[index] = float(row[index])
+                            assert_almost_equal(check_row[index],
+                                                row[index],
+                                                places=DECIMAL_PLACES)
+                        except ValueError:
                             assert_equal(check_row[index], row[index])
     except Exception as exc:
+        shutil.copyfile(predictions_file_path, "%s.new" % check_file_path)
         assert False, traceback.format_exc()
 
 
@@ -1459,6 +1492,12 @@ def i_check_source_label(step, field_id, field_label):
     except KeyError as exc:
         assert False, str(exc)
 
+#@step(r'I check that the source exists')
+def check_source_exists(step, exists=True):
+    if not exists:
+        exists = None
+    source = world.api.get_source(step.source)
+    assert world.api.ok(source) == exists
 
 #@step(r'I create BigML resources uploading train "(.*)" file to evaluate and
 # log evaluation in "(.*)"')
@@ -1749,7 +1788,29 @@ def retrieve_resources(scenario_path, step):
             world.model = retrieve_resource(scenario_path, model_id)
     except:
         pass
-
+    try:
+        with open(os.path.join(scenario_path, "deepnets"), open_mode("r")) \
+            as model_id_file:
+            model_id = model_id_file.readline().strip()
+            world.deepnet = retrieve_resource(scenario_path, model_id)
+    except:
+        pass
+    try:
+        with open(os.path.join(scenario_path, "logistic_regressions"),
+                  open_mode("r")) as model_id_file:
+            model_id = model_id_file.readline().strip()
+            world.logistic_regression = retrieve_resource(scenario_path,
+                                                          model_id)
+    except:
+        pass
+    try:
+        with open(os.path.join(scenario_path, "linear_regressions"),
+                  open_mode("r")) as model_id_file:
+            model_id = model_id_file.readline().strip()
+            world.linear_regression = retrieve_resource(scenario_path,
+                                                        model_id)
+    except:
+        pass
 
 
 #@step(r'I have previously executed "(.*)" or reproduce it with arguments (.*)$')
@@ -1758,6 +1819,8 @@ def i_have_previous_scenario_or_reproduce_it(step, scenario, kwargs):
                                (i_check_create_source, False),
                                (i_check_create_dataset, False),
                                (i_check_create_model, False)],
+                 'scenario1_img_dn': [(i_create_composite_source, True),
+                                      (i_check_create_composite, False)],
                  'scenario1_r': [(i_create_all_resources, True),
                                  (i_check_create_source, False),
                                  (i_check_create_dataset, False),
@@ -1821,6 +1884,10 @@ def i_have_previous_scenario_or_reproduce_it(step, scenario, kwargs):
                                  (i_check_create_source, False),
                                  (i_check_create_dataset, False),
                                  (i_check_create_lr_model, False)],
+                'scenario1_dn': [(i_create_all_dn_resources,True),
+                                 (i_check_create_source, False),
+                                 (i_check_create_dataset, False),
+                                 (i_check_create_dn_model, False)],
                 'scenario1_pca': [(i_create_all_pca_resources, True),
                                   (i_check_create_source, False),
                                   (i_check_create_dataset, False),
