@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -136,8 +136,8 @@ def i_check_output_file(step, output=None, check_file=None):
                             '', check_contents,
                             flags=re.S)
     if check_contents != output_file_contents:
-        #with open("%s" % check_file, "w") as bck_file:
-            # bck_file.write(output_file_contents)
+        with open("%s" % check_file, "w") as bck_file:
+            bck_file.write(output_file_contents)
         eq_(check_contents, output_file_contents)
 
 
