@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -22,6 +22,7 @@
 
 
 import sys
+import os
 
 from bigml.util import get_csv_delimiter
 from bigml.io import UnicodeReader
@@ -46,8 +47,11 @@ class TstReader():
            `objective_field`: field_id of the objective field
         """
         self.test_set = test_set
+        self.directory = None
         if test_set.__class__.__name__ == "StringIO":
             self.test_set = UTF8Recoder(test_set, BIGML_SYS_ENCODING)
+        else:
+            self.directory = os.path.dirname(test_set)
         self.test_set_header = test_set_header
         self.fields = fields
         if (objective_field is not None and
@@ -72,6 +76,15 @@ class TstReader():
         self.headers = None
         self.raw_headers = None
         self.exclude = []
+        self.image_fields = []
+        try:
+            self.image_fields = [column for column in
+                                 sorted(fields.fields_by_column_number.keys())
+                                 if fields.fields[fields.field_id(column)].get(
+                                    "optype") == "image"]
+        except ValueError as exc:
+            sys.exit(exc)
+
         if test_set_header:
             self.headers = next(self.test_reader)
             # validate headers against model fields excluding objective_field,
@@ -127,6 +140,10 @@ class TstReader():
 
         """
         row = next(self.test_reader)
+        if self.directory and self.image_fields:
+            for index, row_item in enumerate(row):
+                if index in self.image_fields:
+                    row[index] = os.path.join(self.directory, row_item)
         return row
 
     def dict(self, row, filtering=True):
