@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -202,6 +202,22 @@ def read_datasets(path):
     return datasets
 
 
+def read_sources(path, read_all=False):
+    """Reads last source id from a file.
+
+    """
+    sources = []
+    for line in fileinput.input([path]):
+        if line.rstrip().startswith("source/"):
+            sources.append(line.rstrip())
+    if read_all:
+        return sources
+    try:
+        return sources[-1]
+    except KeyError:
+        return None
+
+
 def read_json_filter(path):
     """Reads a json filter from a file.
 
